<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d связь';
$lang['%d associations'] = '%d связей';
$lang['%d album including'] = '%d альбом включает';
$lang['%d albums including'] = '%d альбомов включает';
$lang['%d physical'] = '%d реальная';
$lang['%d physical'] = '%d реальных';
$lang[' and %d virtual'] = ' и %d виртуальная';
$lang[' and %d virtual'] = ' и %d виртуальных';
$lang['%d album moved'] = '%d альбом перемещен';
$lang['%d albums moved'] = '%d альбомы перемещены';
$lang['%d group'] = '%d группа';
$lang['%d groups'] = '%d групп';
$lang['%d member'] = '%d участник';
$lang['%d members'] = '%d участников';
$lang['%d tag'] = '%d слово';
$lang['%d tags'] = '%d слов';
$lang['%d user comment rejected'] = '%d комментарий посетителя отклонен';
$lang['%d user comments rejected'] = '%d комментариев посетителей отклонено';
$lang['%d user comment validated'] = '%d комментарий посетителя принят';
$lang['%d user comments validated'] = '%d комментариев посетителей принято';
$lang['%d user deleted'] = '%d пользователь удален';
$lang['%d users deleted'] = '%d пользователей удалено';
$lang['%d user'] = '%d пользователь';
$lang['%d users'] = '%d пользователей';
$lang['%d waiting for validation'] = '%d ожидает проверки';
$lang['Actions'] = 'Действия';
$lang['Activate'] = 'Активировать';
$lang['Add/delete a permalink'] = 'Добавить/удалить постоянную ссылку';
$lang['Add a tag'] = 'Добавить слово';
$lang['Add a user'] = 'Добавить пользователя';
$lang['Add group'] = 'Добавить группу';
$lang['Add'] = 'Добавить';
$lang['Allow user registration'] = 'Разрешить регистрацию пользователей';
$lang['Apply to sub-albums'] = 'Применить к вложенным альбомам';
$lang['Associated'] = 'Связаны';
$lang['Batch management'] = 'Пакетная обработка';
$lang['Caddie management'] = 'Управление корзиной';
$lang['Caddie'] = 'Корзина';
$lang['Albums authorized thanks to group associations'] = 'Альбомы разрешены благодаря  группе ассоциаций';
$lang['Album manual order was saved'] = 'Ручной порядок альбомов был сохранен';
$lang['Check for upgrade failed for unknown reasons.'] = 'Проверка обновлений не удалась по неизвестным причинам.';
$lang['Check for upgrade'] = 'Проверить обновления';
$lang['Comments for all'] = 'Комментарии для всех';
$lang['Current name'] = 'Текущее название';
$lang['Database'] = 'База данных';
$lang['Deactivate'] = 'Выключить';
$lang['Delete Representant'] = 'Удалить представителя';
$lang['Delete selected tags'] = 'Удалить выбранные слова';
$lang['Delete selected users'] = 'Удалить выбранных пользователей';
$lang['Deletions'] = 'Удаления';
$lang['Deny selected groups'] = 'Отмена выбора групп';
$lang['Deny selected users'] = 'Отмена выбора пользователей';
$lang['Description'] = 'Описание';
$lang['Display options'] = 'Варианты показа';
$lang['Dissociated'] = 'Не связанные';
$lang['Does not represent'] = 'Нет представителя';
$lang['Edit selected tags'] = 'Редактировать выделенные слова';
$lang['Edit tags'] = 'Редактировать слова';
$lang['Email admins when a new user registers'] = 'Сообщать администратору когда зарегистрировался новый посетитель';
$lang['Email admins when a valid comment is entered'] = 'Сообщать администратору когда появился комментарий';
$lang['Email admins when a comment requires validation'] = 'Сообщать администратору когда появился комментарий для проверки';
$lang['Environment'] = 'Окружение';
$lang['Form'] = 'Действия';
$lang['Gallery title'] = 'Название галереи';
$lang['Grant selected groups'] = 'Разрешить доступ выбранным группам';
$lang['Grant selected users'] = 'Разрешить доступ выбранным пользователям';
$lang['Group name'] = 'Название группы';
$lang['Groups'] = 'Группы';
$lang['Guests'] = 'Гости';
$lang['History'] = 'История';
$lang['Informations'] = 'Информация';
$lang['Install'] = 'Установить';
$lang['Link all album photos to a new album'] = 'Привязать все фотографии альбома к новому альбому';
$lang['Link all album photos to some existing albums'] = 'Привязать все фотографии альбома к существующим альбомам';
$lang['Linked albums'] = 'Связать альбомы';
$lang['Lock gallery'] = 'Заблокировать галерею';
$lang['Maintenance'] = 'Обслуживание';
$lang['Edit album permissions'] = 'Управлять разрешением для альбомов';
$lang['Manage permissions for group "%s"'] = 'Управление разрешениями для группы "%s"';
$lang['Manage permissions for user "%s"'] = 'Управление разрешениями для пользователя "%s"';
$lang['Manage tags'] = 'Управление словами';
$lang['Members'] = 'Участники';
$lang['Metadata synchronized from file'] = 'Метаданные синхронизированы с файлом';
$lang['Move albums'] = 'Переместить альбом';
$lang['Move'] = 'Перемещение';
$lang['Name'] = 'Название';
$lang['New name'] = 'Новое название';
$lang['New parent album'] = 'Новый родительский альбом';
$lang['New tag'] = 'Новое слово';
$lang['Number of comments per page'] = 'Количество комментариев на странице';
$lang['Number of rates'] = 'Количество оценок';
$lang['Number of thumbnails to create'] = 'Количество создаваемых миниатюр';
$lang['Only private albums are listed'] = 'Показаны только частные альбомы';
$lang['Operating system'] = 'Операционная система';
$lang['Options'] = 'Опции';
$lang['Other private albums'] = 'Другие частные альбомы';
$lang['Page banner'] = 'Надпись на баннере';
$lang['Parent album'] = 'Родительский альбом';
$lang['Path'] = 'Путь';
$lang['Permalink'] = 'Постоянная ссылка';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Постоянная ссылка %s была ранее использована для категории %s. Удалите ее сначала из истории постоянных ссылок';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Имя постоянной ссылки должно состоять из a-z, A-Z, 0-9, "-" или "_". Оно не должно быть числовым или начинаться с числа с "-"';
$lang['Permalink %s is already used by album %s'] = 'Постоянная ссылка %s уже используется альбомом %s';
$lang['Permalink history'] = 'История постоянных ссылок';
$lang['Permalinks'] = 'Постоянные ссылки';
$lang['Permission denied'] = 'Доступ запрещен';
$lang['Permission granted thanks to a group'] = 'Доступ для группы разрешен';
$lang['Permission granted'] = 'Доступ разрешен';
$lang['Photo informations updated'] = 'Информация о фотографии обновлена';
$lang['Plugins'] = 'Плагины';
$lang['Position'] = 'Номер';
$lang['Preferences'] = 'Настройки';
$lang['Properties'] = 'Свойства';
$lang['Random photo'] = 'Случайная фотография';
$lang['Rating by guests'] = 'Оценки от гостей';
$lang['Rating'] = 'Оценки';
$lang['Reject'] = 'Отклонить';
$lang['Representant'] = 'Представитель';
$lang['Representation of albums'] = 'Представитель альбомов';
$lang['Representative'] = 'Представитель';
$lang['Represents'] = 'Представляет';
$lang['Save order'] = 'Сохранить порядок';
$lang['Save to permalink history'] = 'Сохранить историю постоянных ссылок';
$lang['Select at least one album'] = 'Выберите хотя бы один альбом';
$lang['Select at least one photo'] = 'Выберите по крайней мере одну фотографию';
$lang['Select at least one user'] = 'Выберите хотя бы одного пользователя';
$lang['Show info'] = 'Показать информацию';
$lang['Site manager'] = 'Управление сайтами';
$lang['Status'] = 'Статус';
$lang['Statistics'] = 'Статистика';
$lang['Storage album'] = 'Альбом для хранения';
$lang['Sum of rates'] = 'Суммарная оценка';
$lang['Tag "%s" already exists'] = 'Слово "%s" уже есть';
$lang['Tag "%s" was added'] = 'Слово "%s" добавлено';
$lang['Tag selection'] = 'Выбор слов';
$lang['The %d following tags were deleted'] = '%d указанных слов удалено';
$lang['Uninstall'] = 'Удалить';
$lang['Use the default photo sort order (defined in the configuration file)'] = 'Использовать порядок сортировки фотографий по умолчанию (определенный в конфигурационном файле)';
$lang['User comments validation'] = 'Проверка комментариев посетителей';
$lang['Users'] = 'Пользователи';
$lang['Validate'] = 'Принять';
$lang['Validation'] = 'Проверка';
$lang['Version'] = 'Версия';
$lang['Virtual albums to move'] = 'Виртуальные альбомы для перемещения';
$lang['Virtual album name'] = 'Название виртуального альбома';
$lang['Webmaster cannot be deleted'] = 'Нельзя удалить Вебмастера';
$lang['You are running on development sources, no check possible.'] = 'Выполняется в режиме разработки, проверка невозможна.';
$lang['You cannot delete your account'] = "Вы не можете удалить свой аккаунт";
$lang['You cannot move an album in its own sub album'] = 'Вы не можете переместить альбом в его собственный внутренний альбом';
$lang['You need to confirm deletion'] = 'Вам нужно подтвердить удаление';
$lang['add tags'] = 'добавить слова';
$lang['Associate to album'] = 'ассоциация с альбомом';
$lang['associate to group'] = 'привязать к группе';
$lang['Authorized'] = 'Разрешено';
$lang['Add a virtual album'] = 'Добавить виртуальный альбом';
$lang['Authorize users to add comments on selected albums'] = 'Авторизованные пользователи могут добавлять комментарии к выбранным альбомам';
$lang['The name of an album must not be empty'] = 'Название альбома не может быть пустым';
$lang['Lock albums'] = 'Закрытые альбомы';
$lang['Private'] = 'Частные альбомы';
$lang['Public'] = 'Общедоступные альбомы';
$lang['Find a new representant by random'] = 'Найти нового представителя случайным образом';
$lang['Public / Private'] = 'Общедоступные / Приватные';
$lang['Manage authorizations for selected albums'] = 'Управление авторизацией для выбранных альбомов';
$lang['Virtual album added'] = 'Виртуальный альбом добавлен';
$lang['Virtual album deleted'] = 'Виртуальный альбом удален';
$lang['Access type'] = 'Тип доступа';
$lang['Comments'] = 'Комментарии';
$lang['Information data registered in database'] = 'Информация зарегистрирована в базе данных';
$lang['Default display'] = 'Вид по умолчанию';
$lang['The gallery URL is not valid.'] = 'Некорректный URL галереи';
$lang['Main'] = 'Главная';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'На странице может быть от 5 до 50 комментариев.';
$lang['Configuration'] = 'Настройки';
$lang['confirm'] = 'подтверждение';
$lang['delete album'] = 'удалить альбом';
$lang['Dissociate from album'] = 'отделить альбом';
$lang['dissociate from group'] = 'отвязать от группы';
$lang['edit album permissions'] = 'редактировать разрешения альбома';
$lang['Album updated successfully'] = 'Информация об альбоме успешно добавлена.';
$lang['photos per page'] = 'фотографий на странице';
$lang['High definition enabled'] = 'Доступно высокое разрешение';
$lang['File'] = 'файл';
$lang['Filesize'] = 'размер файла';
$lang['first photo added on %s'] = 'первая фотография добавлена %s';
$lang['Forbidden'] = 'Запрещено';
$lang['global mode'] = 'групповой режим';
$lang['group "%s" added'] = 'группа "%s" добавлена';
$lang['group "%s" deleted'] = 'группа "%s" удалена';
$lang['group "%s" updated'] = 'группа "%s" обновлена';
$lang['group'] = 'группа';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Название группы не должно содержать " и \' или быть пустым.';
$lang['This name is already used by another group.'] = 'Это название уже используется для другой группы.';
$lang['High definition'] = 'Большое разрешение';
$lang['jump to album'] = 'быстро перейти в альбом';
$lang['jump to photo'] = 'перейти к фотографии';
$lang['leave'] = 'оставить';
$lang['Lock'] = 'Блокировка';
$lang['Locked'] = 'Заблокировано';
$lang['manage album photos'] = 'управлять элементами альбома';
$lang['manage sub-albums'] = 'Управление вложенными альбомами';
$lang['Manage'] = 'Управление';
$lang['maximum height'] = 'максимальная высота';
$lang['maximum width'] = 'максимальная ширина';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Время выполнения превышено, обработка должна быть продолжена [Рассчетное время: %d сек].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Время выполнения превышено, обработка должна быть продолжена [Рассчетное время: %d сек].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Время подготовки списка пользователей для рассылки ограничено. Остальные пользователи не выведены.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Время для отправки почты ограничено. Другие письма пропущены.';
$lang['To send ?'] = 'Отправить?';
$lang['Last send'] = 'Последнее отправленное';
$lang['email'] = 'email';
$lang['User'] = 'Пользователь';
$lang['Complementary mail content'] = 'Содержание письма';
$lang['See you soon,'] = 'Пока,';
$lang['Go to'] = 'Перейти к ';
$lang['Hello'] = 'Привет ';
$lang['New photos were added'] = 'Были добавлены новые фотографии';
$lang['on'] = ' в ';
$lang['between'] = 'между ';
$lang['and'] = ' и ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Вебмастер подписал Вас на получение уведомлений по почте.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Вы подписались на получение уведомлений по почте.';
$lang['To subscribe'] = 'Для подписки';
$lang['If you encounter problems or have any question, please send a message to'] = 'Если у Вас возникнут проблемы или вопросы, пожалуйста, напишите ';
$lang['[NBM] Problems or questions'] = 'Проблемы и вопросы';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Вебмастер удалил подписку на получение уведомлений по почте.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Вы удалили подписку на получение уведомлений по почте.';
$lang[', click on'] = ', щелкните на ';
$lang['To unsubscribe'] = 'Чтобы отменить подписку';
$lang['With blank value, gallery title will be used'] = 'Если не заполнено, будет использовано название галереи';
$lang['Notification'] = 'Уведомления';
$lang['Error when sending email to %s [%s].'] = 'Ошибка отправки почты для %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Письмо отправлено для %s [%s].';
$lang['%d mail was sent.'] = 'Отправлено письмо: %d.';
$lang['%d mails were sent.'] = 'Отправлено писем: %d.';
$lang['%d mail was not sent.'] = 'Не отправлено письмо: %d.';
$lang['%d mails were not sent.'] = 'Не отправлено писем: %d.';
$lang['No mail to send.'] = 'Нет писем для отправки.';
$lang['There is no available subscribers to mail.'] = 'Нет пользователей, которым можно было бы отправить почту.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Пользователи доступны, если есть новые элементы уведомлений.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Возможно, нет подписанных пользователей (только webmaster может видеть это).';
$lang['No user to send notifications by mail.'] = 'Нет пользователей, чтобы послать уведомления почтой.';
$lang['New photos added'] = 'Новые фотографии добавлены';
$lang['Subscribe to notification by mail'] = 'Подписаться на уведомления по почте';
$lang['Unsubscribe from notification by mail'] = 'Отписаться от уведомлений по почте';
$lang['Parameter'] = 'Параметры';
$lang['Continue processing treatment'] = 'Продолжить обработку обращения';
$lang['Complementary mail content'] = 'Дополнительное содержание письма';
$lang['Add detailed content'] = 'Добавить дополнительное содержание';
$lang['Send mail as'] = 'Отправить письмо от';
$lang['Send mail to users'] = 'Отправить письмо пользователю';
$lang['Send'] = 'Отправка';
$lang['Options'] = 'Параметры';
$lang['Subscribed'] = 'В списке рассылки';
$lang['Subscribe'] = 'Список рассылки';
$lang['Parameters'] = 'Параметры';
$lang['Select recipients'] = 'Выбрать получателей';
$lang['Subscribe/unsubscribe users'] = 'Добавление/удаление пользователей в список рассылки';
$lang['Unsubscribed'] = 'Не в списке рассылки';
$lang['%d parameter was updated.'] = '%d параметр обновлен.';
$lang['%d parameters were updated.'] = '%d параметров обновлено.';
$lang['%d user was not updated.'] = '%d пользователь не обновлен.';
$lang['%d users were not updated.'] = '%d пользователей не обновлено.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Пользователь %s [%s] удален из списка рассылки.';
$lang['User %s [%s] was added to the subscription list.'] = 'Пользователь %s [%s] добавлен в список рассылки.';
$lang['%d user was updated.'] = '%d пользователь изменен.';
$lang['%d users were updated.'] = '%d пользователей изменено.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Пользователь %s [%s] не удален из списка рассылки.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Пользователь %s [%s] не добавлен в список рассылки.';
$lang['User %s [%s] added.'] = 'Пользователь %s [%s] добавлен.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Внимание: при добавлении/удалении в список рассылки будет отправлено уведомление пользователям';
$lang['Send mail on HTML format'] = 'Отправить письмо в HTML формате';
$lang['Include display of recent photos grouped by dates'] = 'Включить показ недавних фотографий, сгруппированных по датам';
$lang['Available only with HTML format'] = 'Возможно только в HTML формате';
$lang['no write access'] = 'нет доступа на запись';
$lang['Permissions'] = 'Разрешения';
$lang['private'] = 'приватная';
$lang['public'] = 'общедоступная';
$lang['Purge never used notification feeds'] = 'очистить неиспользуемые каналы уведомлений';
$lang['Purge sessions'] = 'очистить сессии';
$lang['randomly represented'] = 'случайный представитель';
$lang['registration date'] = 'дата регистрации';
$lang['clean'] = 'очистить';
$lang['remove remote listing.xml file'] = 'удалить удаленный файл listing.xml';
$lang['generate listing'] = 'создать листинг';
$lang['generate file listing.xml on remote site'] = 'создать файл listing.xml на удаленном сайте';
$lang['Create this site'] = 'Создать этот сайт';
$lang['A local listing.xml file has been found for'] = 'Локальный файл listing.xml file был найден ';
$lang['read local listing.xml and update'] = 'читать локальный файл listing.xml и обновить';
$lang['test'] = 'тест';
$lang['test this remote site'] = 'тестировать этот удаленный сайт';
$lang['remove tags'] = 'удалить слова';
$lang['Repair and optimize database'] = 'исправить и оптимизировать базу данных';
$lang['selection'] = 'отмеченные';
$lang['set to'] = 'изменить на';
$lang['singly represented'] = 'выбранный представитель';
$lang['This site already exists'] = 'Такой сайт уже есть';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Создать новый сайт: (введите URL в create_listing_file.php)';
$lang['created'] = 'создан';
$lang['delete'] = 'удален';
$lang['delete this site and all its attached elements'] = 'удалить этот сайт и все прикрепленные элементы';
$lang['deleted'] = 'удален';
$lang['an error happened'] = 'произошла ошибка';
$lang['file create_listing_file.php on remote site was not found'] = 'файл create_listing_file.php не найден на удаленном сайте';
$lang['Local'] = 'Локальный';
$lang['Remote'] = 'Удаленный';
$lang['synchronize'] = 'синхронизировать';
$lang['update the database from files'] = 'обновить базу данных из файлов';
$lang['status'] = 'статус';
$lang['Directory'] = 'Папка';
$lang['sub-albums'] = 'вложенные альбомы';
$lang['synchronize metadata'] = 'синхронизировать метаданные';
$lang['target'] = 'изменить';
$lang['Thumbnail'] = 'миниатюра';
$lang['title'] = 'Название';
$lang['Album list management'] = 'Управление альбомами';
$lang['Piwigo configuration'] = 'Настройка PhpWebGallery';
$lang['Edit album'] = 'Редактирование альбома';
$lang['Group management'] = 'Управление группами';
$lang['User list'] = 'Список пользователей';
$lang['Edit photo information'] = 'Редактировать всю информацию о фотографии';
$lang['Thumbnail creation'] = 'Создание миниатюр';
$lang['Database synchronization with files'] = 'Синхронизация базы данных с файлами';
$lang['all'] = 'все';
$lang['photos without thumbnail (jpeg and png only)'] = 'фотографии без миниатюры (только jpeg и png)';
$lang['height must be a number superior to'] = 'высота должна быть числом больше';
$lang['width must be a number superior to'] = 'ширина должна быть числом больше';
$lang['for the file format'] = 'для файла формата';
$lang['No missing thumbnail'] = 'Миниатюры есть у всех изображений';
$lang['Photo unreachable or no support'] = 'Фотография недоступна или поддержка не возможна';
$lang['GD version'] = 'версия GD';
$lang['Miniaturization parameters'] = 'Параметры миниатюризации';
$lang['generated in'] = 'создано за';
$lang['Results of miniaturization'] = 'Результаты миниатюризации';
$lang['General statistics'] = 'Общая статистика';
$lang['max time'] = 'максимальное время';
$lang['average time'] = 'среднее время';
$lang['min time'] = 'минимальное время';
$lang['number of miniaturized photos'] = 'число фотографий с миниатюрами';
$lang['total time'] = 'общее время';
$lang['for this file format'] = 'для этого формата файла';
$lang['unit mode'] = 'одиночный режим';
$lang['Unlocked'] = 'Разблокировать';
$lang['unset'] = 'очистить';
$lang['Update albums informations'] = 'Обновить информацию об альбоме';
$lang['Update photos information'] = 'Обновить информацию о фотографии';
$lang['Synchronize'] = 'Синхронизация';
$lang['reduce to single existing albums'] = 'объединить в один существующий альбом';
$lang['Choose an option'] = 'Выберите параметры';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'показать максимум информации (добавленные альбомы и фотографии, удаленные альбомы и фотографии)';
$lang['Piwigo version differs on the remote site'] = 'версия PhpWebGallery отличается на удаленном сайте';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Версии create_listing_file.php на удаленном сайте и PhpWebGallery должны быть одинаковыми';
$lang['listing.xml file was not found'] = 'файл listing.xml не найден';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'файл listing.xml не найден на удаленном сайте. Этот файл создается при выборе команды "создать листинг" в Управлении сайтами';
$lang['Error list'] = 'Список ошибок';
$lang['Errors caption'] = 'Обозначение ошибки';
$lang['Detailed informations'] = 'Детальная информация';
$lang['File/directory read error'] = 'Ошибка чтения файла/папки';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Нет доступа к файлу или папке (возможно они отсутствуют или доступ к ним запрещен)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'для этого типа файлов нужна миниатюра. Миниатюры должны находиться в подпапке "thumbnail" папки категории. Имя файла миниатюры должно начинаться с указанного в конфигурации префикса, расширение должно быть одним из нижеперечисленных:';
$lang['missing thumbnail'] = 'отсутствуют миниатюры';
$lang['albums deleted in the database'] = 'альбомы удалены из базы данных';
$lang['photos deleted from the database'] = 'фотографии удалены из базы данных';
$lang['photos candidates for metadata synchronization'] = 'фотографии, предложенные для синхронизации';
$lang['photos informations synchronized with files metadata'] = 'информация о фотографиях синхронизировалась с метаданными файлов';
$lang['errors during synchronization'] = 'ошибок синхронизации';
$lang['albums added in the database'] = 'альбомы добавлены в базу данных';
$lang['photos added in the database'] = 'фотографии добавлены в базу данных';
$lang['photos updated in the database'] = 'фотографии обновлены в базе данных';
$lang['Search for new images in the directories'] = 'Поиск новых изображений в папках';
$lang['added'] = 'добавлена';
$lang['deleted'] = 'удалена';
$lang['Metadata synchronization results'] = 'Результаты синхронизации метаданных';
$lang['only perform a simulation (no change in database will be made)'] = 'только тестировать (не вносить изменения в базу данных)';
$lang['[Simulation]'] = '[Тест]';
$lang['Simulation'] = 'Тест';
$lang['directories + files'] = 'папки и файлы';
$lang['only directories'] = 'только папки';
$lang['synchronize files structure with database'] = 'синхронизировать файловую структуру с базой данных';
$lang['synchronize files metadata with database photos informations'] = 'синхронизируйте метаданные файлов с информацией о фотографиях базы данных';
$lang['even already synchronized photos'] = 'даже уже просинхронизированные фотографии';
$lang['Used metadata'] = 'Используемые метаданные';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Название папки и файла должно состоять из букв, цифр, "-", "_" и "."';
$lang['wrong filename'] = 'неверное имя файла';
$lang['Upload'] = 'Загрузка';
$lang['user "%s" added'] = 'пользователь "%s" added';
$lang['User status'] = 'Статус пользователя';
$lang['user_status_admin'] = 'Администратор';
$lang['user_status_generic'] = 'Общий';
$lang['user_status_guest'] = 'Гость';
$lang['user_status_normal'] = 'Пользователь';
$lang['user_status_webmaster'] = 'Вебмастер';
$lang['Virtual album'] = 'Виртуальный альбом';
$lang['Waiting'] = 'Ожидающие';
$lang['default'] = 'по умолчанию';
$lang['Toggle \'default group\' property'] = 'Сделать/убрать \'по умолчанию\'';
$lang['Advanced features'] = 'Расширенные функции';
$lang['Specials'] = 'Спец функции';
$lang['Overall'] = 'Вся';
$lang['Year'] = 'Год';
$lang['Month'] = 'Месяц';
$lang['Day'] = 'День';
$lang['Pages seen'] = 'Страниц просмотрено';
$lang['Time'] = 'время';
$lang['IP'] = 'IP';
$lang['Element'] = '';
$lang['Section'] = 'раздел';
$lang['Tags'] = 'Метки';
$lang['Save page visits by guests'] = 'Сохранять страницы посещенные гостями';
$lang['Save page visits by users'] = 'Сохранять страницы посещенные пользователями';
$lang['Save page visits by administrators'] = 'Сохранить страницы посещенные администраторами';
$lang['An information email was sent to group "%s"'] = 'Информационное письмо отправлено для группы "%s"';
$lang['Send an information email to group members'] = 'Отправить информационное письмо для группы';
$lang['Group'] = 'Группа';
$lang['[%s] Visit album %s'] = '[%s] Просмотреть альбом %s';
$lang['Hello,'] = 'Привет,';
$lang['See you soon.'] = 'До встречи.';
$lang['Discover album:'] = 'Откройте для себя альбом:';
$lang['Mail content'] = 'Содержание';
$lang['none'] = 'нет';
$lang['high'] = 'большой';
$lang['other'] = 'другой';
$lang['Element type'] = 'Тип элемента';
$lang['Image id'] = 'id изображения';
$lang['Summary'] = 'Суммарно';
$lang['%d line filtered'] = '%d линия отфильтрована';
$lang['%d lines filtered'] = '%d линий отфильтровано';
$lang['%d guest'] = '%d гость';
$lang['%d guests'] = '%d гостей';
$lang['Hour'] = 'Час';
$lang['guest'] = 'гость';
$lang['default values'] = 'значение по умолчанию';
$lang['High filesize'] = 'Большой размер файла';
$lang['Guest cannot be deleted'] = 'Гость не может быть удален';
$lang['Default user cannot be deleted'] = 'Пользователь по умолчанию не может быть удален';
$lang['Purge history detail'] = 'очистить историю';
$lang['Purge history summary'] = 'очистить всю историю';
$lang['Check integrity'] = 'Проверка совместимости';
$lang['Anomaly'] = 'Неисправность';
$lang['Correction'] = 'Корректировка';
$lang['Automatic correction'] = 'Автоматическая коррекция';
$lang['Impossible automatic correction'] = 'Автоматическая коррекция невозможна';
$lang['Correction applied with success'] = 'Коррекция успешно применена';
$lang['Correction applied with error'] = 'Коррекция применена с ошибками';
$lang['%d anomaly has been detected.'] = 'Обнаружена %d неисправность.';
$lang['%d anomalies have been detected.'] = 'Обнаружено %d неисправностей.';
$lang['%d anomaly has been corrected.'] = 'Скорректирована %d неисправность.';
$lang['%d anomalies have been detected corrected.'] = 'Скорректировано %d неисправностей.';
$lang['%d anomaly has not been corrected.'] = 'Не скорректирована %d неисправность.';
$lang['%d anomalies have not been corrected.'] = 'Не скорректировано %d неисправностей.';
$lang['Go to %s or %s for more informations'] = 'Смотрите %s или %s для получения дополнительной информации';
$lang['the forum'] = 'форум';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = 'значение %s в файле не верно, так как exif не поддерживается';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s нужно отключить в файле config_local.inc.php';
$lang['Main "guest" user does not exist'] = 'Статус пользователя "гость" больше не существует';
$lang['Main "guest" user status is incorrect'] = 'Статус пользователя "гость" некорректен';
$lang['Default user does not exist'] = 'Пользователь по умолчанию больше не существует';
$lang['Main "webmaster" user does not exist'] = 'Пользователь "webmaster" больше не существует';
$lang['Main "webmaster" user status is incorrect'] = 'Статус пользователя "webmaster" некорректен';
$lang['User "%s" created with "%s" like password'] = 'Пользователь "%s" создан с паролем "%s"';
$lang['Status of user "%s" updated'] = 'Статус пользователя "%s" обновлен';
$lang['add new photos to caddie'] = 'добавить новые фотографии в корзину';
$lang['No display'] = 'Не показывать';
$lang['Classic display'] = 'Классический вид';
$lang['Hoverbox display'] = 'Вид Hoverbox';
$lang['Mail address is obligatory for all users'] = 'Адрес электронной почты обязателен для всех пользователей';
$lang['Minimum privacy level'] = 'Минимальный уровень защиты';
$lang['Privacy level'] = 'Уровень защиты';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Контакты';
$lang['Level 2'] = 'Друзья';
$lang['Level 4'] = 'Семья';
$lang['Level 8'] = 'Администрация';
$lang['Reinitialize check integrity'] = 'Повторить проверку целостности';
$lang['Check all'] = 'Отметить все';
$lang['Uncheck all'] = 'Снять все отметки';
$lang['Check automatic corrections'] = 'Отметить автокоррекцию';
$lang['Apply selected corrections'] = 'Применить выбранные корректировки';
$lang['Ignore selected anomalies'] = 'Игнорировать отмеченные неисправности';
$lang['Refresh'] = 'Обновить';
$lang['The anomaly will be ignored until next application version'] = 'Неисправности будут игнорироваться до установки следующей версии скрипта';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Корректировка неисправностей отменит факт их игнора';
$lang['%d anomaly has been ignored.'] = '%d неисправность была проигнорирована.';
$lang['%d anomalies have been ignored.'] = 'Было проигнорировано неисправностей: %d';
$lang['Plugins which need upgrade'] = 'Плагины, требующие обновлений';
$lang['Plugin list'] = 'Список плагинов';
$lang['Check for updates'] = 'Проверка обновлений';
$lang['Other plugins'] = 'Другие плагины';
$lang['Last revisions'] = 'Последние изменения';
$lang['Delete'] = 'Удалить';
$lang['Are you sure you want to delete this plugin?'] = 'Уверены, что хотите удалить этот плагин?';
$lang['Are you sure you want to install this plugin?'] = 'Уверены, что хотите установить этот плагин?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Уверены, что хотите обновить? Проверьте, не нужна ли этой версии деинсталляция.';
$lang['%s has been successfully upgraded.'] = '%s успешно обновлен.';
$lang['Plugin has been successfully copied'] = 'Плагин успешно скопирован';
$lang['You might go to plugin list to install and activate it.'] = 'Вы можете перейти к списку плагинов для его установки и активации.';
$lang['Can\'t create temporary file.'] = 'Невозможно создать временный файл.';
$lang['Can\'t download archive.'] = 'Невозможно скачать архив.';
$lang['Can\'t read or extract archive.'] = 'Невозможно прочитать или распаковать архив.';
$lang['An error occured during extraction (%s).'] = 'Ошибка в процессе распаковки (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Пожалуйста, проверьте права папки "plugins" и подпапок (CHMOD).';
$lang['Can\'t connect to server.'] = 'Невозможно соединиться с сервером.';
$lang['Purge compiled templates'] = 'Очистить созданные шаблоны';
$lang['ACCESS_0'] = 'Свободный доступ';
$lang['ACCESS_1'] = 'Доступно для всех';
$lang['ACCESS_2'] = 'Доступно для избранных';
$lang['ACCESS_3'] = 'Доступно для администраторов';
$lang['ACCESS_4'] = 'Доступно для вебмастера';
$lang['ACCESS_5'] = 'Недоступно';
$lang['Support'] = 'Поддержка';
$lang['Documentation'] = 'Документация';
$lang['A new version of Piwigo is available.'] = 'Доступна новая версия Piwigo.';
$lang['Piwigo Administration'] = 'Администрация Piwigo';
$lang['Piwigo version'] = 'Версия Piwigo';
$lang['You are running the latest version of Piwigo.'] = 'Запущена последняя версия Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Установленная версия %s [%s] не совместима с версией [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Чтобы воспользоваться всеми возможностями скрипта, обновите систему, иначе скрипт может работать некорректно';
$lang['Deleted on'] = 'Удалено';
$lang['Last hit'] =  'Последние просмотренные';
$lang['GD library is missing'] = 'Библиотека GD отсутствует';
$lang['Templates'] = 'Шаблоны';
$lang['Extend for templates'] = 'Расширение для шаблонов';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] =
 'Заменить исходные шаблоны на пользовательские из подпапки template-extension';
$lang['Replacers (customized templates)'] = 'Заменяющий (пользовательский шаблон)';
$lang['Original templates'] = 'Исходный шаблон';
$lang['Optional URL keyword'] = 'Опциональное ключевое слово URL';
$lang['Templates configuration has been recorded.'] = 'Templates configuration has been recorded.';
$lang['All optimizations have been successfully completed.'] = 'Все оптимизации успешно завершены.';
$lang['Optimizations have been completed with some errors.'] = 'Оптимизации завершены с ошибками.';
$lang['Modify information'] = 'Modify information';
$lang['edit album'] = 'редактировать информацию об этом альбоме';
$lang['nothing'] = 'ничего';
$lang['overrides existing values with empty ones'] = 'замена существующих значений пустыми';
$lang['manage photo ranks'] = 'изменить ранг фотографии';
$lang['Manage photo ranks'] = 'Редактировать оценку фотографии';
$lang['Edit ranks'] = 'Изменить порядок';
$lang['No photo in this album'] = 'В этом альбоме нет фотографий';
$lang['Images manual order was saved'] = 'Указанный порядок изображений сохранен';
$lang['ranks'] = 'порядок';
$lang['Drag to re-order'] = 'Перетащите чтобы изменить порядок';
$lang['Quick Local Synchronization'] = 'Быстрая синхронизация';
$lang['No photo can be deleted'] = 'Нет фото для удаления';
$lang['Delete selected photos'] = 'Удалить выбранные фото';
$lang['%d photo was deleted'] = '%d фото удалено';
$lang['%d photos were deleted'] = '%d фото удалено';
$lang['Unable to check for upgrade.'] = 'Невозможно проверить обновление.';
$lang['Date'] = 'Дата';
$lang['Operation in progress'] = 'Обработка обращения.';
$lang['Please wait...'] = 'Пожалуйста, подождите...';
$lang['Downloads'] = 'Загрузки';
$lang['Released on'] = 'Выпуск';
$lang['Number of downloads'] = 'Число скачиваний';
$lang['Piwigo Announcements Newsletter'] = 'Piwigo информационная рассылка';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Оставайтесь на связи с проектом Piwigo, подпишитесь на информационную рассылку Piwigo. Вы получите письмо, как только будет доступен новый релиз (иногда письма будут содержать корректировку ошибок безопасности, о которых Вы должны знать и исправить), или когда произойдет какое-то важное событие с проектом. Это всего несколько электронных писем в год.';
$lang['Subscribe %s'] = 'Подписка %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Подписать %s на Piwigo информационную рассылку';
$lang['Purge search history'] = 'Очистить историю поиска';
$lang['Hide'] = 'Спрятать';
$lang['Password is missing. Please enter the password.'] = 'Пароль не верен. Пожалуйста, повторите попытку.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Подтверждение пароля отсутствует. Пожалуйста, подтвердите выбранный пароль.';
$lang['Password confirmation error.'] = 'Ошибка подтверждения пароля.';
$lang['Allow users to edit their own comments'] = 'Позволить пользователям редактировать свои комментарии';
$lang['Allow users to delete their own comments'] = 'Позволить пользователям удалять их комментарии';
$lang['Email administrators when a comment is modified'] = 'Уведомить администратора по почте, когда комментарий изменен';
$lang['Email administrators when a comment is deleted'] = 'Уведомить администратора по почте, когда комментарий удален';
$lang['Cannot delete the old permalink !'] = 'Старая постоянная ссылка не может быть удалена!';
$lang['Hit'] = 'Популярное';
$lang['Tools'] = 'Инструменты';
$lang['Photos'] = 'Фотографии';
$lang['Themes'] = 'Темы';
$lang['Instructions to use Piwigo'] = 'Инструкция по использованию Piwigo';
$lang['Installed Themes'] = 'Установленные темы';
$lang['Add New Theme'] = 'Добавить новую тему';
$lang['Forbid this theme to users'] = 'Запретить использование этой темы пользователям';
$lang['Set as default theme for unregistered and new users'] = 'Установить тему по умолчанию для новых и незарегистрированных пользователей';
$lang['unknown'] = 'неизвестен';
$lang['Upload Photos'] = 'Загрузить фотографии';
$lang['Drop into album'] = 'Закинуть в альбом';
$lang['+ Add an upload box'] = '+ Добавить поле для загрузки';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Создайте "%s" каталог в корне установленной Вами Piwigo';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Дайте доступ для записи (chmod 777) к "%s" каталогу в корне установленной Вами Piwigo';
$lang['existing album'] = 'существующий альбом';
$lang['create a new album'] = 'создать новый альбом';
$lang['Album name'] = 'Название альбома';
$lang['Album "%s" has been added'] = 'Категория "%s" добавлена';
$lang['Uploaded Photos'] = 'Загруженные фотографии';
$lang['%d photos uploaded'] = '%d фотографий загружено';
$lang['Privacy level set to "%s"'] = 'Установить уровень доступа "%s"';
$lang['Album "%s" now contains %d photos'] = 'Категория "%s" содержит сейчас %d фотографий';
$lang['Manage this set of %d photos'] = 'Редактировать этот набор из %d фотографий';
$lang['Select files'] = 'Выбрать файлы';
$lang['Everybody'] = 'Все';
$lang['Who can see these photos?'] = 'Кто может смотреть эти фотографии?';
$lang['The websize maximum width must be a number between %d and %d'] = 'Максимальная ширина изображения должна быть числом между %d и %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'Максимальная высота изображения должна быть числом между %d и %d';
$lang['The websize image quality must be a number between %d and %d'] = 'Качество изображения должно быть числом между %d и%d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'Максимальная ширина миниатюры должна быть числом  %d и %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'Максимальная высота миниатюры должна быть числом между %d и %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'Качество миниатюры должно быть числом между %d и %d';
$lang['Settings'] = 'Установки';
$lang['Web size photo'] = 'Размер фотографии для интернета';
$lang['Resize'] = 'Изменить размеры';
$lang['Maximum Width'] = 'Максимальная ширина';
$lang['pixels'] = 'пикселей';
$lang['Maximum Height'] = 'Максимальная высота';
$lang['Image Quality'] = 'Качество изображения';
$lang['Save Settings'] = 'Сохранить установки';
$lang['Your configuration settings are saved'] = 'Ваши настройки конфигурации сохранены';
$lang['Active Themes'] = 'Активные темы';
$lang['Add write access to the "%s" directory'] = 'Добавьте права записи для "%s" директории';
$lang['Administration Home'] = 'Панель администрирования';
$lang['Change Admin Colors'] = 'Изменить цвет административной панели';
$lang['Delete this theme'] = 'Удалить эту тему';
$lang['Directory does not exist'] = 'Директория не существует';
$lang['Download,'] = 'Загрузить,';
$lang['FTP + Synchronization'] = 'FTP + Синхронизация';
$lang['Get Support on Piwigo Forum'] = 'Обратитесь за помощью на Piwigo форум';
$lang['Help Me'] = 'Помощь';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Эта тема не может быть активизирована, поскольку родительская тема отсутствует: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Эта тема не может быть удалена, потому что другие темы зависят от нее: %s';
$lang['Inactive Themes'] = 'Неактивные темы';
$lang['Install on your computer,'] = 'Установите на Ваш компьютер,';
$lang['Make this theme available to users'] = 'Сделать эту тему доступной для пользователей';
$lang['Page end'] = 'Конец страницы';
$lang['Piwigo Uploader'] = 'Piwigo загрузчик';
$lang['Read Piwigo Documentation'] = 'Читайте документацию Piwigo';
$lang['Start pLoader and add your photos.'] = 'Откройте pLoader и добавьте свои фотографии.';
$lang['Switch to clear or dark colors for administration'] = 'Выбрать светлые или темные тона для панели администирования';
$lang['Theme has been successfully installed'] = 'Тема была успешно установлена';
$lang['Visit Gallery'] = 'Перейти на сайт';
$lang['Visit Piwigo project website'] = 'посмотрите сайт проекта Piwigo ';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader заменяет <em>Piwigo Загрузчик</em>. С помощью pLoader Вы можете локально подготовить Ваши фотографии и загрузить их в Вашу фотогалерею Piwigo.';
$lang['Guest Settings'] = 'Установки пользователя Гость';
$lang['Main Page'] = 'Главная страница';
$lang['Photo Page'] = 'Страница фотографии';
$lang['Activate Navigation Bar'] = 'Активизировать навигационную панель';
$lang['Activate Navigation Thumbnails'] = 'Активизировать навигацию по миниатюрам';
$lang['Activate icon "%s"'] = 'Активизировать иконку "%s"';
$lang['Activate field "%s"'] = 'активизировать поле "%s"';
$lang['Photo Properties'] = 'Свойства фотографии';
$lang['Allow user customization'] = 'Разрешить пользователям изменять внешний вид галереи';
$lang['Languages'] = 'Языки';
$lang['Installed Languages'] = 'предустановленные языки';
$lang['Add New Language'] = 'Добавить новый язык';
$lang['Language has been successfully installed'] = 'Язык был успешно установлен';
$lang['Select:'] = 'выбрать:';
$lang['None'] = 'ни один';
$lang['Invert'] = 'перевернуть';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Невозможный деактивировать эту тему, у Вас должна оставаться по крайней мере одна тема.';
$lang['Webmaster status is required.'] = 'Требуется статус веб мастера.';
$lang['Bound Theme'] = 'связанная тема';
$lang['Allow rating'] = 'Разрешить оценивать';
$lang['Select at least one comment'] = 'Выберите по крайней мере один комментарий';
$lang['Active Plugins'] = 'Активные плагины';
$lang['Inactive Plugins'] = 'Неактивные плагины';
$lang['Missing Plugins'] = 'Потерянные плагины';
$lang['Uninstalled Plugins'] = 'Удаленные плагины';
$lang['By %s'] = ' %s';
$lang['Visit plugin site'] = 'Страница плагина';
$lang['Active Languages'] = 'Активировать языки';
$lang['Delete this language'] = 'Удалить этот язык';
$lang['Forbid this language to users'] = 'Сделать недоступным этот язык для пользователей';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Невозможный деактивировать этот язык, сначала установите другой язык как значение по умолчанию.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Невозможный дезактивировать этот язык, у Вас должен быть по крайней мере один язык.';
$lang['Inactive Languages'] = 'Деактивировать язык';
$lang['Make this language available to users'] = 'Сделать этот язык доступным для пользователей';
$lang['Set as default language for unregistered and new users'] = 'Установить язык по умолчанию для незарегистрированных и новых пользователей';
$lang['Add Photos'] = 'Добавить фотографии';
$lang['Download'] = 'Загрузить';
$lang['The following tag was deleted'] = 'Следущие метки были удалены';
$lang['Miscellaneous'] = 'Разное';
$lang['Virtual Links'] = 'Виртуальные ссылки';
$lang['Templates configuration has been recorded.'] = 'Конфигурация шаблона перезаписана.';
$lang['Modify information'] = 'Информация по изменению';
$lang['There is no other language available.'] = 'Нет других доступных языков.';
$lang['There is no other plugin available.'] = 'Нет других доступных плагинов.';
$lang['There is no other theme available.'] = 'Нет других доступных тем.';
$lang['By rank'] = 'По рейтингу';
$lang['Manual order'] = 'Сортировать вручную';
$lang['Add another set of photos'] = 'Добавить фотографии';
$lang['Order of menubar items has been updated successfully.'] = 'Порядок расположения элементов меню изменен успешно.';
$lang['This theme was not designed to be directly activated'] = 'В этой теме не предусмотрена активация напрямую';
$lang['Who can see this photo?'] = 'Кто может смотреть эту фотографию?';
$lang['Pending Comments'] = 'Проверка комментариев';
$lang['Menu Management'] = 'Меню';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'В вашем файле php.ini, upload_max_filesize (%sB) больше, чем post_max_size (%sB), вы должны изменить это значение';
$lang['Exif extension not available, admin should disable exif use'] = 'Расширение Exif не поддерживается, администратор должен отключить использование Exif';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Размер загружаемого файла превышает значение upload_max_filesize, указанное в php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Размер загружаемого файла превышает значение post_max_size, указанное in php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Размер загружаемого файла превышает значение MAX_FILE_SIZE, указанное в html форме';
$lang['The uploaded file was only partially uploaded'] = 'Файл был загружен лишь частично';
$lang['No file was uploaded'] = 'Файл не был загружен';
$lang['Missing a temporary folder'] = 'Потеряна временная папка';
$lang['Failed to write file to disk'] = 'Не удалось записать файл на диск';
$lang['File upload stopped by extension'] = 'Загрузка файла остановлена из-за его расширения';
$lang['Unknown upload error'] = 'Ошибка загрузки не известна';
$lang['Error on file "%s" : %s'] = 'Ошибка в файле "%s" : %s';
$lang['automatic order'] = 'автоматический режим';
$lang['manual order'] = 'самостоятельный режим';
$lang['Albums automatically sorted'] = 'Автоматическая сотрировка альбомов';
$lang['Keep high definition'] = 'Сохранить большое разрешение';
$lang['The high definition maximum width must be a number between %d and %d'] = 'Максимальная ширина большого разрешения должна быть значением между %d and %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'Максимальная высота большого разрешения должна быть значением между %d and %d';
$lang['The high definition image quality must be a number between %d and %d'] = 'Максимальное качество большого разрешения должно быть значением между  %d and %d';
$lang['Batch Manager'] = 'Пакетный менеджер';
$lang['include child albums'] = 'включает дочерние альбомы';
$lang['Selection'] = 'Выбор';
$lang['Action'] = 'Действие';
$lang['Set author'] = 'Установить автора';
$lang['Set title'] = 'Установить название';
$lang['Set creation date'] = 'Установить дату создания';
$lang['Apply action'] = 'Добавить действие';
$lang['on the %d selected photos'] = 'на %d выбранных фотографиях';
$lang['%d of %d photos selected'] = '%d из %d фотографий выбрано';
$lang['No photo selected, %d photos in current set'] = 'Ниодна фотография не выбрана, в текущем наборе %d фото';
$lang['All %d photos are selected'] = 'Все %d фотографии были выбраны';
$lang['remove this filter'] = 'удалить этот фильтр';
$lang['predefined filter'] = 'переопределить фильтр';
$lang['last import'] = 'последний импорт';
$lang['with no virtual album'] = 'с невиртуальным альбомом';
$lang['duplicates'] = 'дубликаты';
$lang['Add a filter'] = 'Добавить фильтр';
$lang['Remove all filters'] = 'Удалить все фильтры';
$lang['Refresh photo set'] = 'Обновить набор фотографий';
$lang['The whole page'] = 'Все на странице';
$lang['The whole set'] = 'Все в наборе';
$lang['No photo in the current set.'] = 'Нет фотографий в текущем наборе.';
$lang['No photo selected, no action possible.'] = 'Фото не выбрано, действие не возможно.';
$lang['Choose an action'] = 'Выберите действие';
$lang['remove author'] = 'удалить автора';
$lang['Type here the author name'] = 'напечатайте имя автора здесь';
$lang['remove title'] = 'удалить название';
$lang['Type here the title'] = 'напечатайте название здесь';
$lang['remove creation date'] = 'удалить дату создания';
$lang['with no album'] = 'без каких-либо альбомов';
$lang['with no tag'] = 'без каких-либо меток';
$lang['Album photos associated to the following albums: %s'] = 'Фотографии этого альбома связаны со следущими альбомами: %s';
$lang['Delete orphan tags'] = 'Удалить неривязанные метки';
$lang['delete photo'] = 'удалить фотографию';
$lang['Orphan tags deleted'] = 'Непривязанные метки удалены';
$lang['Week starts on'] = 'Неделя начинается с';
$lang['You have %d orphan tags: %s.'] = 'У Вас есть %d непривязанных  меток: %s.';
$lang['Remove from caddie'] = 'Очистить корзину';
$lang['Themes which need upgrade'] = 'Темы, которые нужно обновить';
$lang['Languages which need upgrade'] = 'Языки, которые нужно обновить';
$lang['All themes are up to date.'] = 'Все темы обновлены до последней версии.';
$lang['All plugins are up to date.'] = 'Все плагины обновлены до последней версии.';
$lang['All languages are up to date.'] = 'Все языки обновлены до последней версии.';
$lang['Visit theme site'] = 'Посмотреть полное описание темы';
$lang['Visit language site'] = 'Посмотреть подробную страницу языка';
$lang['New Version'] = 'Новая версия';
$lang['Obsolete Plugins'] = 'Устаревшие плагины';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'ВНИМАНИЕ! По всей вероятности, этот плагин не совместим с данной версией Piwigo.';
$lang['Do you want to activate anyway?'] = 'Всё равно хотите активировать?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'ЭТОТ ПЛАГИН СЕЙЧАС УЖЕ ЯВЛЯЕТСЯ ЧАСТЬЮ ЯДРА PIWIGO! УДАЛИТЕ ЕГО СЕЙЧАС!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ОШИБКА: НЕСМОТРЯ НА ТО, ЧТО ЭТОТ ПЛАГИН УСТАНОВЛЕН, ОН ПОТЕРЯЛСЯ! УДАЛИТЕ ЕГО СЕЙЧАС.';
$lang['new'] = 'новый';
$lang['No results'] = 'Ничего не найдено';
$lang['Searching...'] = 'Выполняется поиск...';
$lang['Type in a search term'] = 'Определите критерий поиска';
$lang['display'] = 'показать';
$lang['Activate icon "new" next to albums and pictures'] = 'Активировать иконку "new" рядом с альбомами и фотографиями';
$lang['Deactivate all'] = 'Деактивировать все';
$lang['Default photos order'] = 'Порядок фотографий по умолчанию';
$lang['Restore'] = 'Восстановить';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Восстановление конфигурации по умолчанию. Ваши настройки плагинов будут потеряны!';
$lang['Show menubar'] = 'Показать меню';
$lang['Regenerate Thumbnails'] = 'Сгенерить миниатюры заново';
$lang['Regenerate Websize Photos'] = 'Сгенерить фотографии web размера заново';
$lang['Thumbnails generation in progress...'] = 'Идет генерация миниатюр ...';
$lang['Photos generation in progress...'] = 'Идет генерация фотографий ...';
$lang['%s thumbnails have been regenerated'] = '%s миниатюр было создано заново';
$lang['%s thumbnails can not be regenerated'] = '%s миниатюр не было создано заново';
$lang['%s photos have been regenerated'] = '%s фотографий было создано заново';
$lang['%s photos can not be regenerated'] = '%s фотографий не было создано заново';
$lang['Updates'] = 'Обновление';
$lang['Update in progress... Please wait.'] = 'Процесс обновления... Пожалуйста, подождите.';
$lang['Ignore this update'] = 'Пропустить это обновление';
$lang['Reset ignored updates'] = 'Сбросить проигнорированные обновления';
$lang['Update All'] = 'Обновить все';
$lang['ERROR'] = 'ОШИБКА';
$lang['Update Complete'] = 'Обновление завершено';
$lang['Piwigo Update'] = 'Обновление Piwigo';
$lang['Extensions Update'] = 'обновление плагинов';
$lang['All extensions are up to date.'] = 'Все плагины обновлены.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Следующие плагины, возможно, не являются совместимыми с новой версией Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Следующие темы, возможно, не являются совместимыми с новой версией Piwigo:';
$lang['I decide to update anyway'] = 'Ну и ладно, всё равно обновить!)';
$lang['Update to Piwigo %s'] = 'Обновление до версии Piwigo %s';
$lang['Two updates are available'] = 'Два апдейта доступны';
$lang['This is a minor update, with only bug corrections.'] = 'Это незначительный апдейт, исправлены небольшие ошибки.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Это основной апдейт, с <a href="%s">новыми восхитительными возможностями</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Некоторые темы и плагины  все же могут быть не доступны.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Вы можете обновиться до версии  Piwigo %s, минуя апдейт до версии Piwigo %s (рекомендуется).';
$lang['Save Template Directory'] = 'Сохранить каталог шаблонов';
$lang['Dump Database'] = 'Дамп базы данных';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Включить данные истории (Предупреждение: память сервера может быть превышена)';
$lang['Unable to write new local directory.'] = 'Не удалось записать новый локальный каталог.';
$lang['Unable to send template directory.'] = 'Не удается отправить каталог шаблонов.';
$lang['Unable to dump database.'] = 'Невозможно сделать дамп базы данных.';
$lang['Some upgrades are available for extensions.'] = 'Для плагинов доступны некоторые обновления.';
$lang['Ignore All'] = 'Пропустить все';
$lang['Crop'] = 'Обрезать';
$lang['Width'] = 'Ширина';
$lang['Height'] = 'Высота';
$lang['Follow Orientation'] = 'Изменить ориентацию';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Если в хотите перегенерить миниатюры, используйте, пожалуйста, <a href="%s">Бач менеджер (Batch Manager)</a>.'; 
$lang['Graphics Library'] = 'Библиотека изображений';
$lang['Add a criteria'] = 'Добавить критерий';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Вы не можете определить порядок сортировки фотографий по умолчанию, так как он переопределен в локальных настройках.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Вы использовали <i>$conf[\'order_by\']</i> в качестве порядка сортировки в локальном файле конфигурации. Этот параметр не рекомендуется для использования. Пожалуйста, удалите его или переименуйте в <i>$conf[\'order_by_custom\']</i> !';
$lang['Learn more'] = 'Узнать больше';
$lang['Rate'] = 'Оценка';
$lang['Average rate'] = 'Средний балл';
$lang['Rate date'] = 'Дата оценки';
$lang['... or '] = '... или ';
$lang['Create'] = 'Создать';
$lang['Start Upload'] = 'Начать загрузку';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Вы используете Flash-загрузчик. Возникли проблемы? Попробуйте <a href="%s">браузерный загрузчик</a>.';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Вы используете браузерный загрузчик. Попробуйте <a href="%s">Flash-загрузчик</a>.';
$lang['Maximum file size: %sB.'] = 'Максимальный размер файла: %sB.';
$lang['Allowed file types: %s.'] = 'Допустимые типы файлов: %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Максимальное разрешение: %dM пикселей (то есть %dx%d пикселей).';
$lang['Manage Permissions'] = 'Настройка прав доступа';
$lang['Photo %s of %s'] = 'Фотография %s из %s';
$lang['show details'] = 'показать подробности';
$lang['hide details'] = 'скрыть подробности';
$lang['Merge tags'] = 'Объединить тэги';
$lang['Select the destination tag'] = 'Выбрать тэг-получатель';
$lang['(this tag will be deleted)'] = '(этот тэг будет удален)';
$lang['Confirm merge'] = 'Подтвердите объединение';
$lang['Merge selected tags'] = 'Объединить выбранные тэги';
$lang['No destination tag selected'] = 'Тэг-получатель не выбран';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Тэги <em>%s</em> объединены в тэг <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Выберите по крайней мере два тэга для объединения';
$lang['Select an album'] = 'Выберите альбом';
$lang['An error has occured during upgrade.'] = 'Во время обновления произошла ошибка.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Во время распаковки произошла ошибка. Пожалуйста, проверьте права доступа к папке установки piwigo.<br><a href="%s">Нажмите, чтобы посмотреть лог ошибки</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo не может получить файлы обновления с сервера';
?>